.. conu documentation master file, created by
   sphinx-quickstart on Fri Nov 10 13:42:30 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

conu - Container Utilities for image testing
=============================================

conu gathers utilities that come in handy when creating tests, provides nice logging for troubleshooting and is easily extensible.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation.rst
   examples.rst
   reference/index.rst
   new_releases.rst

Contribution
=============

In case of issues, questions and suggestions, please, file an issue or pull request on https://github.com/user-cont/conu where conu is stored and maintained.
Before you open issue or pull request please read our contribution guide https://github.com/user-cont/conu/blob/master/CONTRIBUTING.md .

.. toctree::
   :maxdepth: 2
   :caption: Upstream development:

   new_releases.rst
   asciinema.rst
